@@ -5,8 +5,8 @@
 ;; Author: Adam Porter <adam@alphapapa.net>
 ;; Maintainer: Adam Porter <adam@alphapapa.net>
 ;; URL: https://github.com/alphapapa/taxy.el
-;; Version: 0.9
-;; Package-Requires: ((emacs "26.3") (magit-section "3.2.1"))
+;; Version: 0.11
+;; Package-Requires: ((emacs "26.3") (magit-section "3.2.1") (taxy "0.10"))
 ;; Keywords: lisp
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -132,7 +132,7 @@ which blank lines are inserted between sections at that level."
                    (add-face-text-property
                     0 (length taxy-name)
                     (funcall (taxy-magit-section-heading-face-fn taxy) depth)
-                    nil taxy-name)
+                    t taxy-name)
                    (cl-typecase taxy
                      (taxy-magit-section
                       (when (taxy-magit-section-visibility-fn taxy)
@@ -276,8 +276,17 @@ PLIST may be a plist setting the following options:
                     (progn
                       ,(when max-width
                          `(when ,max-width-variable
-                            (setf string (truncate-string-to-width
-                                          string ,max-width-variable nil nil "…"))))
+                            ;; I don't like having to save a copy of the old string for
+                            ;; comparison, but given the way `truncate-string-to-width'
+                            ;; calculates widths, I don't see much alternative.  It would
+                            ;; be nice if it returned nil when no change was made.
+                            (let ((old-string string)
+                                  (new-string (truncate-string-to-width
+                                               string ,max-width-variable nil nil "…")))
+                              (unless (equal old-string new-string)
+                                ;; String was elided: add help-echo.
+                                (put-text-property 0 (length new-string) 'help-echo old-string new-string)
+                                (setf string new-string)))))
                       ,(when face
                          ;; Faces are not defined until load time, while this checks type at expansion
                          ;; time, so we can only test that the argument is a symbol, not a face.
@@ -365,7 +374,7 @@ the items' values for each column."
                  (let* ((column-alist (alist-get column-name formatters nil nil #'equal))
                         (fn (alist-get 'formatter column-alist))
                         (value (funcall fn item depth))
-                        (current-column-size (or (map-elt column-sizes column-name) 0)))
+                        (current-column-size (or (map-elt column-sizes column-name) (string-width column-name))))
                    (setf (map-elt column-sizes column-name)
                          (max current-column-size (string-width* value)))
                    (setf (map-elt column-aligns column-name)
